Method: BOTR::VideoCaption.show

Defined in:
lib/botr/videos/video_caption.rb

.show(video_key) ⇒ BOTR::VideoCaption Also known as: find

Returns a new object with the properties of the caption referenced by the caption_key.

Parameters:

  • caption_key (String)

    key of the caption which information to show

Returns:

  • (BOTR::VideoCaption)

    a new object with the properties of the caption referenced by the caption_key



17
18
19
20
21
22
23
24
25
26
27
28
29
# File 'lib/botr/videos/video_caption.rb', line 17

def show(video_key)
  json = get_request({:method => 'show',
              :caption_key => video_key})
  res = JSON.parse(json.body)

  if json.status == 200
    params = process_show_response(res)
  else
    raise "HTTP Error #{json.status}: #{json.body}"
  end

  return new(params)
end